@@ -11,10 +11,9 @@
 
 namespace KIO
 {
-
-DefaultViewAdapter::DefaultViewAdapter(QAbstractItemView *view, QObject *parent) :
-    KAbstractViewAdapter(parent),
-    m_view(view)
+DefaultViewAdapter::DefaultViewAdapter(QAbstractItemView *view, QObject *parent)
+    : KAbstractViewAdapter(parent)
+    , m_view(view)
 {
 }
 
@@ -53,3 +52,4 @@ void DefaultViewAdapter::connect(Signal signal, QObject *receiver, const char *s
 
 }
 
+#include "moc_defaultviewadapter_p.cpp"
