@@ -290,6 +290,7 @@ KUrlNavigatorPrivate::KUrlNavigatorPrivate(const QUrl &url, KUrlNavigator *qq, K
     });
 
     m_badgeWidgetContainer = new QWidget(q);
+    m_badgeWidgetContainer->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Preferred);
     auto badgeLayout = new QHBoxLayout(m_badgeWidgetContainer);
     badgeLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -890,7 +891,7 @@ void KUrlNavigatorPrivate::updateButtonVisibility()
     }
 
     auto lastButton = m_navButtons.last();
-    for (const auto &button : m_navButtons) {
+    for (const auto &button : std::as_const(m_navButtons)) {
         if (button != lastButton) {
             button->setDrawSeparator(true);
         } else {
@@ -1436,11 +1437,6 @@ void KUrlNavigator::paintEvent(QPaintEvent *event)
             option.palette.setColor(QPalette::Base, palette().alternateBase().color());
         }
         style()->drawPrimitive(QStyle::PE_FrameLineEdit, &option, &painter, this);
-    } else {
-        // Draw primitive only for the input field
-        if (d->m_editable) {
-            style()->drawPrimitive(QStyle::PE_FrameLineEdit, &option, &painter, this);
-        }
     }
 }
 
