@@ -10,7 +10,10 @@
 #include "kiotrashdebug.h"
 #include "transferjob.h"
 
+#ifdef WITH_QTDBUS
 #include <KDirNotify>
+#endif
+
 #include <kio/jobuidelegateextension.h>
 
 #include <KLocalizedString>
@@ -170,7 +173,9 @@ KIO::WorkerResult TrashProtocol::rename(const QUrl &oldURL, const QUrl &newURL,
             return KIO::WorkerResult::fail(impl.lastErrorCode(), impl.lastErrorMessage());
         }
         const QUrl finalUrl = TrashImpl::makeURL(oldTrashId, newFileId, QString());
+#ifdef WITH_QTDBUS
         org::kde::KDirNotify::emitFileRenamed(oldURL, finalUrl);
+#endif
         return KIO::WorkerResult::pass();
     }
 
